@@ -2,20 +2,19 @@
 
 ctLabel<-function(matrixname, n.latent, n.manifest, n.TDpred, n.TIpred, Tpoints, manifestNames, latentNames, TDpredNames, TIpredNames){
   
-  if(matrixname=="T0MEANS") out <- matrix(paste0("T0mean_",latentNames[1:n.latent]),ncol=1)
-  if(matrixname=="T0VAR") out <- indexMatrix(dimension=n.latent,starttext="T0var_",lowerTriangular=TRUE,sep="_",namesvector=latentNames)
-  if(matrixname=='LAMBDA') out <- matrix(paste0('lambda_',rep(1:n.manifest,times=n.latent),rep(latentNames[1:n.latent],each=n.manifest)),nrow=n.manifest)
-  if(matrixname=="MANIFESTMEANS") out <- matrix(paste0('manifestmeans_',manifestNames[1:n.manifest]),nrow=n.manifest,ncol=1)
-  if(matrixname=="MANIFESTVAR") out <- indexMatrix(dimension=n.manifest,starttext="manifestvar_",lowerTriangular=TRUE,sep="_",namesvector=manifestNames)
-  if(matrixname=="DRIFT") out <- indexMatrix(dimension=n.latent,starttext="drift_",symmetrical=FALSE,sep="_",namesvector=latentNames)
+  if(matrixname=="T0MEANS") out <- matrix(paste0("T0m_",latentNames[1:n.latent]),ncol=1)
+  if(matrixname=="T0VAR") out <- indexMatrix(dimension=n.latent,starttext="T0var_",lowerTriangular=TRUE,sep="_",namesvector=latentNames,shortdiag=TRUE)
+  if(matrixname=='LAMBDA') out <- matrix(paste0('lambda_',rep(1:n.manifest,times=n.latent),'_',rep(latentNames[1:n.latent],each=n.manifest)),nrow=n.manifest)
+  if(matrixname=="MANIFESTVAR") out <- indexMatrix(dimension=n.manifest,shortdiag=TRUE,starttext="mvar",lowerTriangular=TRUE,sep="_",namesvector=manifestNames)
+  if(matrixname=="DRIFT") out <- indexMatrix(dimension=n.latent,starttext="drift_",shortdiag=TRUE,symmetrical=FALSE,sep="_",namesvector=latentNames)
   if(matrixname=="CINT") out <- matrix(paste0("cint_",latentNames[1:n.latent]),ncol=1)
-  if(matrixname=="DIFFUSION") out <- indexMatrix(dimension=n.latent,starttext="diffusion_",lowerTriangular=TRUE,sep="_",namesvector=latentNames)
-  if(matrixname=="TRAITVAR") out <- indexMatrix(dimension=n.latent,starttext="traitvar_",lowerTriangular=TRUE,sep="_",namesvector=latentNames)
+  if(matrixname=="DIFFUSION") out <- indexMatrix(dimension=n.latent,starttext="diff_",lowerTriangular=TRUE,sep="_",shortdiag=TRUE,namesvector=latentNames)
+  if(matrixname=="TRAITVAR") out <- indexMatrix(dimension=n.latent,starttext="traitvar_",lowerTriangular=TRUE,shortdiag=TRUE,sep="_",namesvector=latentNames)
   if(matrixname=="T0TRAITEFFECT") out <- indexMatrix(dimension=n.latent,starttext="T0traiteffect_",symmetrical=FALSE,sep="_",namesvector=latentNames,endtext='Trait')
-  if(matrixname=="MANIFESTTRAITVAR") out <- indexMatrix(dimension=n.manifest,starttext="manifesttraitvar_",lowerTriangular=TRUE,sep="_",namesvector=manifestNames)
-  if(matrixname=="MANIFESTMEANS") out <- matrix(paste0("manifestmeans_",manifestNames[1:n.manifest]),ncol=1)
+  if(matrixname=="MANIFESTTRAITVAR") out <- indexMatrix(dimension=n.manifest,starttext="mtraitvar_",shortdiag=TRUE,lowerTriangular=TRUE,sep="_",namesvector=manifestNames)
+  if(matrixname=="MANIFESTMEANS") out <- matrix(paste0("mm_",manifestNames[1:n.manifest]),ncol=1)
   
-  if(matrixname=="TDPREDEFFECT") out <- matrix(paste0("TDeffect_",latentNames[1:n.latent],"_",rep(TDpredNames[1:n.TDpred],each=n.latent)),nrow=n.latent,ncol=n.TDpred)
+  if(matrixname=="TDPREDEFFECT") out <- matrix(paste0("td_",latentNames[1:n.latent],"_",rep(TDpredNames[1:n.TDpred],each=n.latent)),nrow=n.latent,ncol=n.TDpred)
   
   if(matrixname=="TDPREDMEANS") out <- matrix(paste0("mean_",rep(TDpredNames[1:n.TDpred],each=Tpoints),"T",0:(Tpoints-1)),ncol=1)
    
