@@ -15,7 +15,8 @@
 #' @export
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
+#' if (!exists("ctstantestfit")) example(ctstantestfit)
 #' 
 #' #generate and plot samples from prior predictive
 #' priorpred <- ctStanGenerate(ctm = ctstantestfit$ctstanmodelbase,
@@ -39,7 +40,7 @@ ctStanGenerate <- function(ctm,datastruct, optimize=TRUE, is=FALSE,
   
   #problem with multiple cores inside function?
   pp<-ctStanFit(datalong = datastruct[c(1,nrow(datastruct)),,drop=FALSE], 
-    ctstanmodel = ctm,optimize=optimize, optimcontrol=dots,verbose=0,...)
+    ctstanmodel = ctm,optimize=optimize, optimcontrol=dots,verbose=0, nopriors=FALSE,...)
 
   if(parsonly) dat <- pp else{
   
@@ -47,7 +48,7 @@ ctStanGenerate <- function(ctm,datastruct, optimize=TRUE, is=FALSE,
   filled[,ctm$manifestNames] <- -99
   # browser()
   ppf <- ctStanFit(datalong = filled, ctstanmodel = ctm,optimize=optimize, 
-    optimcontrol=dots,fit=FALSE)
+    optimcontrol=dots,fit=FALSE,nopriors=FALSE)
   # pp$standata$Y <- ppf$standata$Y
   ppf$stanfit <- pp$stanfit
   class(ppf) <- c('ctStanFit',class(ppf))
