@@ -1,26 +1,76 @@
-jac<-function(pars,grfunc,step=rep(1e-6,length(pars)), direction=1,whichpars='all',cl=NA){
+log1p_exp <- function(x) log1p(exp(x))
+
+jac<-function(pars,fgfunc,step=rep(1e-6,length(pars)),whichpars='all',
+  lpdifmin=1e-5,lpdifmax=1, cl=NA,verbose=1){
   if('all' %in% whichpars) whichpars <- 1:length(pars)
+  base <- fgfunc(pars)
   hessout <- flexsapply(cl = cl, cores = 1, whichpars, function(i) {
-    stepsize = step[i]*direction
+    if(verbose) message('### Par ',i,'###')
+    stepsize = step[i]
     uppars<-rep(0,length(pars))
     uppars[i]<-1
     accepted <- FALSE
     count <- 0
-    while(!accepted){
-      upgrad<- suppressMessages(suppressWarnings(try({
-        (grfunc(pars+uppars*stepsize) / stepsize + grfunc(pars+uppars*stepsize*-1) / (stepsize*-1))/2
-      },silent=TRUE)))
-      
-      accepted <- !'try-error' %in% class(upgrad)
-      if(!accepted) stepsize <- stepsize * .1
-      if(count > 20) stop('Couldnt compute Hessian!')
+    lp <- list()
+    steplist <- list()
+    for(di in 1:2){
+      count <- 0
+      accepted <- FALSE
+      stepchange = 0
+      stepchangemultiplier = 1
+      while(!accepted && count < 15){
+        stepchangemultiplier <- max(stepchangemultiplier,.11)
+        count <- count + 1
+        lp[[di]] <- fgfunc(pars+uppars*stepsize*ifelse(di==2,-1,1))
+        accepted <- !'try-error' %in% class(lp[[di]])
+        if(accepted){
+          lpdiff <- base[1] - lp[[di]][1]
+          # if(lpdiff > 1e100) browser()
+          if(lpdiff < lpdifmin) {
+            if(verbose) message('Increasing step')
+            if(stepchange == -1) stepchangemultiplier = stepchangemultiplier*.5
+            stepchange <- 1
+            stepsize <- stepsize*(1-stepchangemultiplier)+ (stepsize*10)*stepchangemultiplier
+          }
+          if(lpdiff > lpdifmax){
+            if(verbose) message('Decreasing step')
+            if(stepchange == 1) stepchangemultiplier = stepchangemultiplier * .5
+            stepchange <- -1
+            stepsize <- stepsize*(1-stepchangemultiplier)+ (stepsize*.1)*stepchangemultiplier
+          }
+          if(lpdiff > lpdifmin && lpdiff < lpdifmax && lpdiff > 0) accepted <- TRUE else accepted <- FALSE
+          if(lpdiff < 0){
+            base <- lp[[di]]
+            if(verbose) message('Better log probability found during Hessian estimation...')
+            accepted <- FALSE
+            stepchangemultiplier <- 1
+            stepchange=0
+            count <- 0
+            di <- 1
+          }
+        } else stepsize <- stepsize * 1e-3
+        # if(count > 1) print(paste0(count,'___',stepsize,'___',lpdiff))
+      }
+      steplist[[di]] <- stepsize
     }
-    rbind(upgrad)
+    # browser()
+    grad<- suppressMessages(suppressWarnings(try({
+      (attributes(lp[[1]])$gradient / steplist[[di]] + attributes(lp[[2]])$gradient / (steplist[[di]]*-1))/2
+    },silent=TRUE)))
+    rbind(grad)
   })
   return((hessout+t(hessout))/2)
 }
 
-findstepsize <- function(est,func,eps=1e-3,maxlpd=.1,minlpd=1e-4){
+hesscalc <- function(sf,step){ #input stanfit, get hessian
+  smf <- stan_reinitsf(sf$stanmodel,sf$standata)
+  fgfunc <- function(x) rstan::log_prob(smf,x,gradient=TRUE)
+  # step=findstepsize(est = sf$stanfit$rawest,func = fgfunc,eps = 1e-2,
+  #   maxlpd = 2*length(sf$stanfit$rawest),minlpd=.1*length(sf$stanfit$rawest))
+  H=jac(pars = sf$stanfit$rawest,fgfunc = fgfunc,step = rep(step,length(sf$stanfit$rawest)))
+}
+
+findstepsize <- function(est,func,eps=1e-3,maxlpd=3,minlpd=1e-3){
   
   fmax=func(est)
   epsbase=.01
@@ -29,8 +79,9 @@ findstepsize <- function(est,func,eps=1e-3,maxlpd=.1,minlpd=1e-4){
   devs <- matrix(NA,nrow=n,ncol=length(est))
   lp<-c()
   epscount <- 0
+  goodcount <- 0
   
-  while(i < n && epscount < 20){
+  while(i < n && goodcount < 5){
     i=i+1
     accepted <- FALSE
     devs[i,] <- rnorm(length(est))*eps
@@ -51,23 +102,69 @@ findstepsize <- function(est,func,eps=1e-3,maxlpd=.1,minlpd=1e-4){
     fl <- sqrt(fl)
     
     frange <- fmax[1]-lp[i]
+    print(frange)
     if(length(good) <=5){
       if(frange < minlpd) eps <- eps * 2
       if(frange > maxlpd) eps <- eps /2
     }
     # message(i)
     # print(eps)
+    if(frange > minlpd && frange < maxlpd) goodcount <- goodcount + 1 else goodcount <- 0
     # 
     if(length(good)>5){
       if(frange < minlpd) epsbase <- epsbase * 2
       if(frange > maxlpd) epsbase <- epsbase / 2
       eps=epsbase/(sqrt(abs(apply(devs,2,function(x) coefficients(lm(fl[good]~abs(x[good])))[-1])))+1e-8)
       epscount <- epscount + 1
+      print(epsbase)
     }
   }
   return(eps)
 }
 
+gradcheck <- function(sf,min=1e-5,seqlength=10,whichpars=NA,
+  offdiags=FALSE,scale=TRUE,finite=FALSE){
+  p <- sf$stanfit$rawest
+  smf <- stan_reinitsf(sf$stanmodel,sf$standata)
+  if(is.na(whichpars[1])) whichpars <- 1:length(p)
+  
+  func<-function(x) log_prob(smf,x)
+  b=func(p)
+  
+  for(pi in whichpars){
+    g <- list()
+    gf=c()
+    devs <- min*2^(1:seqlength)
+    devs=sort(c(devs,-devs,0))
+    for(i in seq_along(devs)){
+      px <- p
+      px[pi] <- p[pi] + devs[i]
+      g[[i]] <- log_prob(smf,px,gradient=TRUE)
+      if(finite) gf[i]<-(func(px)-b)/devs[i]
+    }
+    lp=sapply(g,function(x) x[1])
+    plot(devs,lp,type='l',lwd=2,main=pi)
+    abline(h=lp[devs==0],lty=2)
+    abline(v=0,lty=2)
+    gmat<- sapply(g,function(x) attributes(x)$gradient)
+    if(finite) gfmat=sapply(gf,function(x) x*2)
+    if(scale) gmat <- t(t(gmat)/devs)
+    if(finite && scale) gfmat=t(t(gfmat)/devs)
+    plot(devs,gmat[pi,],type='l',lwd=2,main=pi,ylab='grad')
+    if(finite)  points(devs,gfmat,type='l',lwd=2,lty=2,col=2,main=pi,ylab='grad')
+    abline(v=0,lty=2)
+    abline(h=0,lty=2)
+    if(offdiags){
+      for(i in 1:length(p)){
+        if(i != pi) plot(devs,gmat[i,],type='l',lwd=2,main=paste0(pi,'  ',i),ylab='grad')
+        abline(v=0,lty=2)
+        abline(h=0,lty=2)
+      }
+    }
+  }
+}
+
+
 jacrandom <- function(grfunc, est, eps=1e-4,
   maxlpd=.5, minlpd=1e-5){
   
@@ -222,6 +319,7 @@ getcxxfun <- function(object) {
 #'
 #' @examples
 #' \donttest{
+#' if (!exists("ctstantestfit")) example(ctstantestfit)
 #' sf <- stan_reinitsf(ctstantestfit$stanmodel,ctstantestfit$standata)
 #' }
 stan_reinitsf <- function(model, data,fast=FALSE){
@@ -252,7 +350,10 @@ flexlapply <- function(cl, X, fn,cores=1,...){
 #' @export
 #'
 #' @examples
+#' \donttest{
+#' if (!exists("ctstantestfit")) example(ctstantestfit)
 #' d <- standatact_specificsubjects(ctstantestfit$standata, 1:2)
+#' }
 standatact_specificsubjects <- function(standata, subjects,timestep=NA){
   long <- standatatolong(standata)
   long <- long[long$subject %in% subjects,]
@@ -550,10 +651,13 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
   
   message('Using ',cores,'/', parallel::detectCores(),' available CPU cores')
   
-  # #remove tipreds for first pass
-  TIPREDEFFECTsetup <- standata$TIPREDEFFECTsetup
-  standata$TIPREDEFFECTsetup[,] <- 0L
-  standata$ntipredeffects <- 0L
+  notipredsfirstpass <- FALSE
+  if(init[1] =='random'){# #remove tipreds for first pass
+    notipredsfirstpass <- TRUE
+    TIPREDEFFECTsetup <- standata$TIPREDEFFECTsetup
+    standata$TIPREDEFFECTsetup[,] <- 0L
+    standata$ntipredeffects <- 0L
+  }
   
   if(standata$nindvarying > 0 && standata$intoverpop==0){ #detect subject level pars
     stochastic <- TRUE
@@ -579,7 +683,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
     if(all(init == 0)) init <- rep(0,npars)
     if(length(init) != npars) init=init[1:npars]
     init[is.na(init)] <- 0
-    if(standata$ntipredeffects > 0) init[length(init):(length(init)+1-standata$ntipredeffects)] <- 0
+    if(notipredsfirstpass && standata$ntipredeffects > 0) init[length(init):(length(init)+1-standata$ntipredeffects)] <- 0
     
     
     
@@ -635,7 +739,6 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
         return(out)
       }
       
-      
       if(optimcores==1) target = singletarget #we use this for importance sampling
       if(cores > 1){ #for parallelised computation after fitting, if only single subject
         clctsem=parallel::makeCluster(cores,useXDR=TRUE)
@@ -787,7 +890,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
       
       
       message('Optimizing...')
-      if(length(datadrivenpars) <1 && standata$ntipred ==0) finished <- TRUE
+      if(length(datadrivenpars) <1 && (standata$ntipred ==0 || notipredsfirstpass ==FALSE)) finished <- TRUE
       if(optimcores > 1) parallelStanSetup(cl = clctsem,standata = standata)
       if(optimcores==1) smf<-stan_reinitsf(sm,standata)
       
@@ -859,8 +962,8 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
               nsubjects=ifelse(is.na(whichmcmcpars[1]),NA,standata$nsubjects),
               ndatapoints=standata$ndatapoints,plot=plot)
             if(length(datadrivenpars)>0) init[-datadrivenpars] = optimfit$par else{
-             finished <- TRUE
-             init = optimfit$par
+              finished <- TRUE
+              init = optimfit$par
             }
             # if((optimfit$value-oldlp) < 3.92) finished <- TRUE
             # print(optimfit$value-oldlp)
@@ -868,7 +971,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
           } else finished <- TRUE
         } #finish datadrivenpar loop
         standata$taylorheun <- as.integer(taylorheun)
-        if(standata$ntipred ==0) optimfit <- sgd(init, fitfunc = target,
+        if(standata$ntipred ==0 || !notipredsfirstpass ) optimfit <- sgd(init, fitfunc = target,
           itertol = 1e-3, deltatol= 1e-3,
           whichignore = datadrivenpars,whichmcmcpars=whichmcmcpars,
           nsubjects=ifelse(is.na(whichmcmcpars[1]),NA,standata$nsubjects),
@@ -876,7 +979,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
       }
       
       
-      if(standata$ntipred > 0){
+      if(standata$ntipred > 0 && notipredsfirstpass){
         message('Including TI predictors...')
         # standata$tipredeffectscale <- tipredeffectscale
         standata$dokalmanrows[] <- 1L
@@ -1176,6 +1279,7 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
             attributes(fg)$gradient <- attributes(fg)$gradient[-datadrivenpars]
           }
           # print(fg[1])
+          if(fg[1] < -1e99) class(fg) <- c('try-error',class(fg))
           return(fg)
         }
         
@@ -1193,8 +1297,9 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
         
         # hess <- jacrandom(fgfunc, grinit)
         # browser()
-        eps <- findstepsize(grinit,fgfunc)
-        hess <- jac(pars = grinit,grfunc = gfunc,step = eps,cl=clctsem)
+        # eps <- findstepsize(grinit,fgfunc)
+        hess <- jac(pars = grinit,fgfunc = fgfunc,
+          step = rep(1e-3,length(grinit)),cl=clctsem,verbose=verbose)
         cholcov = try(suppressWarnings(t(chol(solve(-hess)))),silent = TRUE)
         # 
         # if('try-error' %in% class(cholcov)){
@@ -1225,7 +1330,11 @@ stanoptimis <- function(standata, sm, init='random',initsd=.01,sampleinit=NA,
         # }
         # }
         
-        mcov=MASS::ginv(-hess) #-optimfit$hessian)
+        mcov=try(solve(-hess),silent=TRUE)
+        if('try-error' %in% class(mcov)){
+          mcov=MASS::ginv(-hess) 
+          warning('Generalized inverse required for Hessian inversion -- standard errors not trustworthy')
+        }
         
         # if(robust){
         #   message('Getting scores for robust std errors...')
